<?php

/**
 * Blog Eye Plus Theme Customizer
 *
 * @package Blog Eye Plus Plus
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function blog_eye_pluscustomize_register($wp_customize)
{

    $wp_customize->remove_control('blog_eye_blog_style');
    $wp_customize->remove_control('blog_eye_plus_blog_layout');

    //select sanitization function
    function sanitize_select($input, $setting)
    {
        $input = sanitize_key($input);
        $choices = $setting->manager->get_control($setting->id)->choices;
        return (array_key_exists($input, $choices) ? $input : $setting->default);
    }
    $wp_customize->add_setting('blog_eye_plus_blog_style', array(
        'default'        => 'grid',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'sanitize_select',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('blog_eye_plus_blog_style', array(
        'label'      => __('Select Blog plus Style', 'blog-eye-plus'),
        'section'    => 'blog_eye_blog',
        'settings'   => 'blog_eye_plus_blog_style',
        'type'       => 'select',
        'choices'    => array(
            'grid' => __('Grid Style', 'blog-eye-plus'),
            'list' => __('List Style', 'blog-eye-plus'),
            'classic' => __('Classic Style', 'blog-eye-plus'),
        ),
    ));


    $wp_customize->add_setting('blog_eye_plus_post_btntext', array(
        'default'        => __('Read More', 'blog-eye-plus'),
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'refresh',
        'priority'       => 15,
    ));
    $wp_customize->add_control('blog_eye_plus_post_btntext', array(
        'label'      => __('Posts Button Text', 'blog-eye-plus'),
        'description'     => __('You can change post button Continue Reading text.', 'blog-eye-plus'),
        'section'    => 'blog_eye_blog',
        'settings'   => 'blog_eye_plus_post_btntext',
        'type'       => 'text',

    ));

    $wp_customize->add_setting('blog_eye_plus_blog_layout', array(
        'default'        => 'rightside',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'blog_eye_sanitize_select',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('blog_eye_plus_blog_layout', array(
        'label'      => __('Select Blog Layout', 'blog-eye-plus'),
        'description' => __('Right and Left sidebar only show when sidebar widget is available. ', 'blog-eye-plus'),
        'section'    => 'blog_eye_blog',
        'settings'   => 'blog_eye_plus_blog_layout',
        'type'       => 'select',
        'choices'    => array(
            'rightside' => __('Right Sidebar', 'blog-eye-plus'),
            'leftside' => __('Left Sidebar', 'blog-eye-plus'),
            'fullwidth' => __('No Sidebar', 'blog-eye-plus'),
        ),
    ));
}
add_action('customize_register', 'blog_eye_pluscustomize_register', 99);
